<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       ugurozer.com
 * @since      1.0.0
 *
 * @package    cnk_mss_v5
 * @subpackage cnk_mss_v5/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    cnk_mss_v5
 * @subpackage cnk_mss_v5/admin
 * @author     Cenk Işıkgün <cenk.isikgun@gmail.com>
 */
class cnk_mss_v5_Admin {

	private $plugin_name;
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	 
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/cnk_mss_v5-admin.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/cnk_mss_v5-admin.js', array( 'jquery' ), $this->version, false );
	}

	
	
	

	// CNK MSS
	public function cnk_mss_create_db_table() {
	
			$cnk_mss_db_version = '1.0';
			global $wpdb;
			
			$table_name = $wpdb->prefix . 'cnk_mss_content_bank';
			$charset_collate = $wpdb->get_charset_collate();
			
			$sql = "CREATE TABLE $table_name (
				id mediumint(9) NOT NULL AUTO_INCREMENT,
				time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
				user tinytext NOT NULL,
				orderid text NOT NULL,
				text text NOT NULL,
				pdf_url text NOT NULL,
				UNIQUE KEY id (id)
			) $charset_collate;";
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
			dbDelta( $sql );
	
			add_option( 'cnk_mss_db_version', $cnk_mss_db_version );
	
	}
	
	function cnk_mss_tc_kimlik(){
		/*
		 * Kayıt aşaması yeni alanları eklenmesi.
		 */
		
		function cnk_mss_extra_register_fields() {
			$cnk_mss_customer_phone = get_option('cnk_mss_customer_phone');
			$cnk_mss_customer_tc = get_option('cnk_mss_customer_tc');
			$cnk_mss_customer_tc_require = get_option('cnk_mss_customer_tc_require');
			
			?>

			<p class="form-row form-row-first">
				<label for="reg_billing_first_name">
					<?php _e( 'Ad', 'woocommerce' ); ?> <span class="required">*</span></label>
				<input type="text" class="input-text" name="billing_first_name" id="reg_billing_first_name" value="<?php if ( ! empty( $_POST['billing_first_name'] ) ) esc_attr_e( $_POST['billing_first_name'] ); ?>" />
			</p>
			<p class="form-row form-row-last">
				<label for="reg_billing_last_name">
					<?php _e( 'Soyad', 'woocommerce' ); ?> <span class="required">*</span></label>
				<input type="text" class="input-text" name="billing_last_name" id="reg_billing_last_name" value="<?php if ( ! empty( $_POST['billing_last_name'] ) ) esc_attr_e( $_POST['billing_last_name'] ); ?>" />
			</p>
			<div class="clear"></div>
			
			<?php if($cnk_mss_customer_phone == 1): ?>
				<p class="form-row form-row-wide">
					<label for="reg_billing_phone">
						<?php _e( 'Telefon', 'woocommerce' ); ?> <span class="required">*</span></label>
					<input type="text" class="input-text" name="billing_phone" id="reg_billing_phone" value="<?php if ( ! empty( $_POST['billing_phone'] ) ) esc_attr_e( $_POST['billing_phone'] ); ?>" />
				</p>
			<?php endif; ?>
			
			<?php if($cnk_mss_customer_tc == 1): ?>
				<p class="form-row form-row-wide">
					<label for="reg_billing_tc">
						<?php _e( 'TC kimlik numarası', 'woocommerce' ); ?> <?php if($cnk_mss_customer_tc_require == 1): ?><span class="required">*</span><?php endif; ?></label>
					<input type="text" class="input-text" name="billing_tc" id="reg_billing_tc" value="<?php if ( ! empty( $_POST['billing_tc'] ) ) esc_attr_e( $_POST['billing_tc'] ); ?>" />
				</p>
			<?php endif; ?>
		<?php
		
		}
		
		/*
		 * Yeni alanlar zorunlumu?
		 */
		function cnk_mss_validate_extra_register_fields( $username, $email, $validation_errors ) {
			
			$cnk_mss_customer_phone = get_option('cnk_mss_customer_phone');
			$cnk_mss_customer_tc = get_option('cnk_mss_customer_tc');
			$cnk_mss_customer_tc_require = get_option('cnk_mss_customer_tc_require');
			
			if ( isset( $_POST['billing_first_name'] ) && empty( $_POST['billing_first_name'] ) ) {
				$validation_errors->add( 'billing_first_name_error', __( '<strong>Hata</strong>: İsim gerekli!', 'woocommerce' ) );
			}
		
			if ( isset( $_POST['billing_last_name'] ) && empty( $_POST['billing_last_name'] ) ) {
				$validation_errors->add( 'billing_last_name_error', __( '<strong>Hata</strong>: Soyisim Gerekli!.', 'woocommerce' ) );
			}
		
			if($cnk_mss_customer_phone == 1):
				if ( isset( $_POST['billing_phone'] ) && empty( $_POST['billing_phone'] ) ) {
					$validation_errors->add( 'billing_phone_error', __( '<strong>Hata</strong>: Telefon Numarası gerekli!.', 'woocommerce' ) );
				}
			endif;
			
			if($cnk_mss_customer_tc_require == 1):
				if ( isset( $_POST['billing_tc'] ) && empty( $_POST['billing_tc'] ) ) {
					$validation_errors->add( 'billing_phone_tc', __( '<strong>Hata</strong>: TC numarası gerekli!.', 'woocommerce' ) );
				}
			endif;
		}
		
		/*
		 * Yeni alanların kaydı.
		 */
		function cnk_mss_save_extra_register_fields( $customer_id ) {
			if ( isset( $_POST['billing_first_name'] ) ) {
				// WordPress default first name field.
				update_user_meta( $customer_id, 'first_name', sanitize_text_field( $_POST['billing_first_name'] ) );
		
				// WooCommerce billing first name.
				update_user_meta( $customer_id, 'billing_first_name', sanitize_text_field( $_POST['billing_first_name'] ) );
			}
		
			if ( isset( $_POST['billing_last_name'] ) ) {
				// WordPress default last name field.
				update_user_meta( $customer_id, 'last_name', sanitize_text_field( $_POST['billing_last_name'] ) );
		
				// WooCommerce billing last name.
				update_user_meta( $customer_id, 'billing_last_name', sanitize_text_field( $_POST['billing_last_name'] ) );
			}
		
			if ( isset( $_POST['billing_phone'] ) ) {
				// WooCommerce billing phone
				update_user_meta( $customer_id, 'billing_phone', sanitize_text_field( $_POST['billing_phone'] ) );
			}
			
			if ( isset( $_POST['billing_tc'] ) ) {
				// WooCommerce billing phone
				update_user_meta( $customer_id, 'billing_tc', sanitize_text_field( $_POST['billing_tc'] ) );
			}
		}
		
		function cnk_mss_save_additional_account_details( $user_ID ){
			$billing_phone = ! empty( $_POST['billing_phone'] ) ? wc_clean( $_POST['billing_phone'] ) : '';
			update_user_meta( $user_ID, 'billing_phone', $billing_phone );
			
			$billing_tc = ! empty( $_POST['billing_tc'] ) ? wc_clean( $_POST['billing_tc'] ) : '';
			update_user_meta( $user_ID, 'billing_tc', $billing_tc );
		}
		
		//Yeni alanların kullanıcılar sayfasına eklenmesi
		function cnk_mss_add_user_columns($column) {
			$column['telefon'] = 'Telefon';
			$column['tc'] = 'TC Numarası';
		
			return $column;
		}
		
		//data eklenmesi
		function cnk_mss_add_user_column_data( $val, $column_name, $user_id ) {
			$user = get_userdata($user_id);
		
			switch ($column_name) {
				case 'telefon' :
					return $user->billing_phone;
					break;
				case 'tc' :
					return $user->billing_tc;
					break;
				default:
			}
			return;
		}
		
		
		
			
		add_action( 'woocommerce_register_form_start', 'cnk_mss_extra_register_fields' );
		add_action( 'woocommerce_register_post', 'cnk_mss_validate_extra_register_fields', 10, 3 );
		add_action( 'woocommerce_created_customer', 'cnk_mss_save_extra_register_fields' );
		add_action( 'woocommerce_save_account_details', 'cnk_mss_save_additional_account_details' );
		add_filter( 'manage_users_columns', 'cnk_mss_add_user_columns' );
		add_filter( 'manage_users_custom_column', 'cnk_mss_add_user_column_data', 10, 3 );
			
		
		
		
	} // cnk_mss_init
	
	public function add_cnk_menu_item(){
		add_menu_page (
			'WooCommerce - Mesafeli Satış Sözleşmesi',
			'MSS',
			'manage_options',
			'cnk_mss_options',
			array($this, 'cnk_mss_admin_sayfalar'),
			'',
			'100.56'
		);

	}
	
	public function cnk_mss_admin_sayfalar(){
	
		include_once WP_CONTENT_DIR . '/plugins/cnk_mss_v5/admin/partials/cnk_mss_v5-admin-display.php';
		
	}
	
	
	public function cnk_mss_save_mss_page($order_id){
		
		global $wpdb;
		//global $current_user;
		global $woocommerce;
		
		$order = new WC_Order( $order_id );
		$order_meta = get_post_meta($order_id);
		
		$current_user = get_userdata($order_meta[_customer_user][0]);
		
		// Kullanıcı
		
		$eposta = $order->get_billing_email();
		$isim = $order->get_billing_first_name() . ' ' . $order->get_billing_last_name();
		
		
		$tckod = get_user_meta( $current_user->ID, 'billing_tc', true );
		$phone = $order->get_billing_phone();
		
		$billing_f_name = $order->get_billing_first_name();
		$billing_l_name = $order->get_billing_last_name();
		$billing_company = $order->get_billing_company();
		
		$billing_full_name = $billing_f_name . ' ' . $billing_l_name;
		
		$shipping_f_name = $order->get_shipping_first_name();
		$shipping_l_name = $order->get_shipping_last_name();
		$shipping_company = $order->get_shipping_company();
		
		$shipping_full_name = $shipping_f_name . ' ' . $shipping_l_name;
		
		// Adresler
		$faturaAdres = $woocommerce->customer->get_billing_address_1() . ' ' . $woocommerce->customer->get_billing_address_2() . ' ' . $woocommerce->customer->get_billing_postcode() . ' ' . $woocommerce->customer->get_billing_city () . ' ' . $woocommerce->customer->get_country();
		
		$kargoAdres = $woocommerce->customer->get_shipping_address() . ' ' .  $woocommerce->customer->get_shipping_address_2() . ' ' . $woocommerce->customer->get_shipping_postcode() . ' ' . $woocommerce->customer->get_shipping_city() . ' ' . $woocommerce->customer->get_shipping_country();
		
		
		// Sepet Adet Tutar Ürün
		$items = $order->get_items();
		
		$cartitemstext = '';
		
		foreach( $order->get_items() as $item_id => $item ) {
				
				
				$product = apply_filters( 'woocommerce_order_item_product', $order->get_product_from_item( $item ), $item );
				$is_visible        = $product && $product->is_visible();
				
				$productName = apply_filters( 'woocommerce_order_item_name', $item['name'], $item, $is_visible );
				$productQty = apply_filters( 'woocommerce_order_item_quantity_html',  $item['qty'] , $item );
				$productSubtotal = $order->get_formatted_line_subtotal( $item );
				
				$cartitemstext .= '<br />
' . $productName . ' x ' . $productQty . ' : ' . $productSubtotal . '<br />
';
				
				
			}
				
		foreach ( $order->get_order_item_totals() as $key => $total ) {
				
				$cartitemstext .= '<br />
' . $total['label'] . $total['value'] . '<br />
';
				
			}
		
		
		
		$mss_post = get_post(get_option('cnk_mss_content_page')); 
		$mss_post_content = $mss_post->post_content;
		$mss_post_content = apply_filters ("the_content", $mss_post_content);
		
		$mss_post_content = str_replace("[kullanici-adi]", $isim, $mss_post_content);
		$mss_post_content = str_replace("[tc-no]", $tckod, $mss_post_content);
		$mss_post_content = str_replace("[telefon-no]", $phone, $mss_post_content);
		$mss_post_content = str_replace("[e-posta-adresi]", $eposta, $mss_post_content);
		
		$mss_post_content = str_replace("[fatura-kullanici-adi]", $billing_full_name, $mss_post_content);
		$mss_post_content = str_replace("[fatura-firma-adi]", $billing_company, $mss_post_content);
		$mss_post_content = str_replace("[fatura-adresi]", $faturaAdres, $mss_post_content);
		
		$mss_post_content = str_replace("[kargo-kullanici-adi]", $shipping_full_name, $mss_post_content);
		$mss_post_content = str_replace("[kargo-firma-adi]", $shipping_company, $mss_post_content);
		$mss_post_content = str_replace("[kargo-adresi]", $kargoAdres, $mss_post_content);
		
		$mss_post_content = str_replace("[sepet-tutar]", $cartitemstext, $mss_post_content);
		
		$mss_post_content = str_replace("[tarih]", date("d/m/Y"), $mss_post_content);
		
		$upload_dir = wp_upload_dir();

		if (!file_exists($upload_dir.'/mss')) {
			mkdir($upload_dir['basedir'].'/mss', 0777, true);
		}
		
		if (!file_exists($upload_dir.'/mss/'.date('Y'))) {
			mkdir($upload_dir['basedir'].'/mss/'.date('Y'), 0777, true);
		}
		
		if (!file_exists($upload_dir['basedir'].'/mss/'.date('Y').'/'.date('m'))) {
			mkdir($upload_dir['basedir'].'/mss/'.date('Y').'/'.date('m'), 0777, true);
		}

		function turkce($str)
		{
			$str = strip_tags($str);
			$str = str_replace("‘", "'", $str);
			$str = str_replace("’", "'", $str);
			$str = str_replace("₺", 'TL', $str);
			$str = str_replace("&#8378;", 'TL', $str);
			$str = str_replace("&nbsp;", ' ', $str);
			
			$str=mb_convert_encoding($str, "ISO-8859-9","UTF-8");
			
			return $str;
		}

		$pdf_name = date('d-m-Y').'-mss-order-'.$order_id;
		$pdf_path = $upload_dir['basedir'].'/mss/'.date('Y').'/'.date('m').'/'. $pdf_name . '.pdf';
		$pdf_url = $upload_dir['baseurl'].'/mss/'.date('Y').'/'.date('m').'/'. $pdf_name . '.pdf';
		
		
		$pdf_content = turkce($mss_post_content);
		
		
		require(WP_CONTENT_DIR . '/plugins/cnk_mss_v5/admin/partials/fpdf.php');
		
		$pdf = new FPDF();
		$cellWidth = $pdf->GetStringWidth($pdf_content);
		$pdf->AddPage();
		$pdf->AddFont('arial_2','','arial_2.php');
		$pdf->SetFont('arial_2','',12);
		$pdf->MultiCell(0,10,$pdf_content,0);
		
		$pdf->Output($pdf_path,'F');	
		
		
		
		// DB
		$table_name = $wpdb->prefix . 'cnk_mss_content_bank';
		
		$wpdb->insert( 
			$table_name, 
			array( 
				'time' 		=> current_time( 'mysql' ),
				'orderid' 	=> $order_id, 
				'user' 		=> $isim . ' - ' . $eposta . ' - ' . $phone, 
				'text' 		=> $mss_post_content,
				'pdf_url'	=> $pdf_url
			) 
		);
		
	}
	
	
	public function add_order_email_instructions( $order, $sent_to_admin ) {
	
		// if ( ! $sent_to_admin ) {
			
			$cnk_order_post = $order->post;
			$cnk_order_id = $cnk_order_post->ID;
			
			global $wpdb;
			$table_name = $wpdb->prefix . 'cnk_mss_content_bank';
		
			foreach( $wpdb->get_results("SELECT * FROM $table_name WHERE orderid = $cnk_order_id") as $key => $row) {
					// each column in your row will be accessible like this
					echo '<div class="cnk_mss_email" style="max-width:100%; margin:10px auto; border:solid 1px #ccc; padding:5px;">';
						echo '<h2>Mesafeli Satış Sözleşmesi</h2>';
						
						echo '<a href="'.$row->pdf_url.'">Mesafeli Satış Sözleşmenizin PDF dosyası için tıklayınız</a><br/>';
						
						// echo '<h3>Sözleşme Metni</h3>';
						// echo '<div>'. $row->text .'</div>';
					echo '</div>';
				}
			
		// }
	}
	
	/*
	**************************************************************
	* CNK - Login Redirrect
	**************************************************************
	*/
	function cnk_mss_redirect() {
		if (
			! is_user_logged_in()
			&& (is_checkout())
		) {
			wp_redirect(get_permalink( get_option('woocommerce_myaccount_page_id') ));
			exit;
		}
	}
	
}
?>