<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       ugurozer.com
 * @since      1.0.0
 *
 * @package    cnk_mss_v5
 * @subpackage cnk_mss_v5/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    cnk_mss_v5
 * @subpackage cnk_mss_v5/public
 * @author     Cenk Işıkgün <cenk.isikgun@gmail.com>
 */
class cnk_mss_v5_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in cnk_mss_v5_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The cnk_mss_v5_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/cnk_mss_v5-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in cnk_mss_v5_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The cnk_mss_v5_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/cnk_mss_v5-public.js', array( 'jquery' ), $this->version, false );

	}


	
	
	
	/*
	**************************************************************
	* CNK - Woocommerce Template Override
	**************************************************************
	*/
	
	function woo_adon_plugin_template( $template, $template_name, $template_path ) {
		
		
		
		global $woocommerce;
		$_template = $template;
		
		if ( ! $template_path ) 
			$template_path = $woocommerce->template_url;
		
		$plugin_path  = WP_CONTENT_DIR . '/plugins/cnk_mss_v5/woocommerce/templates/';
		
		// Look within passed path within the theme - this is priority
		$template = locate_template(
			array(
				$template_path . $template_name,
				$template_name
			)
		);
		
		if( ! $template && file_exists( $plugin_path . $template_name ) )
			$template = $plugin_path . $template_name;
		
		if ( ! $template )
			$template = $_template;
		
		return $template;
		
		
	}
	
	/*
	**************************************************************
	* CNK - Replace Terms Content
	**************************************************************
	*/
	
	function modify_the_content( $content ) {

		$mss_page = wc_get_page_id('terms');
		$page_id = get_the_ID();
		
		if($mss_page != $page_id){
			return $content;
			exit; 
		}
	
		global $current_user;
	
		// $current_user = wp_get_current_user();
		
		// Kullanıcı
		$eposta = $current_user->user_email;
		$isim = $current_user->user_firstname . ' ' . $current_user->user_lastname;
		$userid = $current_user->ID;
		
		$tckod = get_user_meta( $current_user->ID, 'billing_tc', true );
		$phone = get_user_meta( $current_user->ID, 'billing_phone', true );
		
		$billing_f_name = get_user_meta( $userid, 'billing_first_name', true );
		$billing_l_name = get_user_meta( $userid, 'billing_last_name', true );
		$billing_company = get_user_meta( $userid, 'billing_company', true );
		
		$billing_full_name = $billing_f_name . ' ' . $billing_l_name;
		
		$shipping_f_name = get_user_meta( $userid, 'shipping_first_name', true );
		$shipping_l_name = get_user_meta( $userid, 'shipping_last_name', true );
		$shipping_company = get_user_meta( $userid, 'shipping_company', true );
		
		$shipping_full_name = $shipping_f_name . ' ' . $shipping_l_name;
		
		global $woocommerce;
		
		// Adresler		
		$faturaAdres = $woocommerce->customer->get_billing_address_1() . ' ' . $woocommerce->customer->get_billing_address_2() . ' ' . $woocommerce->customer->get_billing_postcode() . ' ' . $woocommerce->customer->get_billing_city () . ' ' . $woocommerce->customer->get_billing_country();
		
		$kargoAdres = $woocommerce->customer->get_shipping_address() . ' ' .  $woocommerce->customer->get_shipping_address_2() . ' ' . $woocommerce->customer->get_shipping_postcode() . ' ' . $woocommerce->customer->get_shipping_city() . ' ' . $woocommerce->customer->get_shipping_country();
		
		
		// Sepet Adet Tutar Ürün
		$cart_subtotal = strip_tags($woocommerce->cart->get_cart_subtotal());
		
		$cartitems = $woocommerce->cart->get_cart( );
		$cartitemstext = '';
		$toplamSepet = 0;
		$kargoucret = strip_tags($woocommerce->cart->get_cart_shipping_total());
		
		$cart_total_price = strip_tags($woocommerce->cart->get_cart_total());
		
		foreach($cartitems as $cartitem => $values){
				$_product = $values['data']->post;
				$price = get_post_meta($values['product_id'] , '_price', true);
	
				$cartitemstext .= '<br />' . $values['quantity'] . ' Adet - ' . $_product->post_title . '. Fiyat: ₺' . $price;	
				$toplamSepet++;
			}
			
		$cartitemstext .= '<br />Ara Toplam : ' . $toplamSepet . ' Adet/<strong>' . $cart_subtotal . '</strong>';
		$cartitemstext .= '<br />Kargo Ücretleri : <strong>' . $kargoucret . '</strong>';
		$cartitemstext .= '<br /> ---------------------------------- <br /> Genel Toplam : <strong>' . $cart_total_price . '</strong><br />';
		
		
		
		// Değiştirme
		// $content = apply_filters ("the_content", $post->post_content);
		
		$content = str_replace("[kullanici-adi]", $isim, $content);
		$content = str_replace("[tc-no]", $tckod, $content);
		$content = str_replace("[telefon-no]", $phone, $content);
		$content = str_replace("[e-posta-adresi]", $eposta, $content);
		
		$content = str_replace("[fatura-kullanici-adi]", $billing_full_name, $content);
		$content = str_replace("[fatura-firma-adi]", $billing_company, $content);
		$content = str_replace("[fatura-adresi]", $faturaAdres, $content);
		
		$content = str_replace("[kargo-kullanici-adi]", $shipping_full_name, $content);
		$content = str_replace("[kargo-firma-adi]", $shipping_company, $content);
		$content = str_replace("[kargo-adresi]", $kargoAdres, $content);
		
		$content = str_replace("[sepet-tutar]", $cartitemstext, $content);
		
		$content = str_replace("[tarih]", date("d/m/Y"), $content);
		
					
		// Sonuç
		return $content;
		
	}
	
	/*
	**************************************************************
	* CNK - Replace Terms Content
	**************************************************************
	*/
	
	
	function cnk_terms_popup_content( ) {
		$cnk_mss_popup_active = get_option('cnk_mss_popup_active');
		
		if($cnk_mss_popup_active == 1):
		
		global $woocommerce, $post ;
		
		$woocommerce_terms_page_id = get_option('woocommerce_terms_page_id');
		
		?>
		
		<script type="text/javascript" >				
			jQuery(document).ready(function($) {
				
				
				
				jQuery( window ).bind( 'updated_checkout', function() {
					$('.wc-terms-and-conditions a').attr('href','Javascript:void(0);');
					$('.wc-terms-and-conditions a').addClass('cnk_mss_term_popup_link');
					
					
					$('.cnk_mss_term_popup_link').click(function(){
						$('#cnk_mss_popup_content').fadeIn('fast');

				
						$('#cnk_mss_popup_content #close_popup').click(function () {
							$('#cnk_mss_popup_content').fadeOut('fast');
						});
					});
					
				});
			});
			
		</script>
		
		<div id="cnk_mss_popup_content" class="cnk" style="display:none" >
			<a id="close_popup">X</a>
			<div class="cnk_mss_popup_header">
				<h3><?php echo get_post_field('post_title',$woocommerce_terms_page_id);?></h3>
				<hr/>
			</div>
			<div class="cnk_mss_popup_body">
				<?php 
					
					$term_content_post = get_post($woocommerce_terms_page_id);
					$term_content = $term_content_post->post_content;
					$term_content = apply_filters('the_content', $term_content);
					$term_content = str_replace(']]>', ']]&gt;', $term_content);
					
					global $current_user;
	
					// $current_user = wp_get_current_user();
					
					// Kullanıcı
					$eposta = $current_user->user_email;
					$isim = $current_user->user_firstname . ' ' . $current_user->user_lastname;
					$userid = $current_user->ID;
					
					$tckod = get_user_meta( $current_user->ID, 'billing_tc', true );
					$phone = get_user_meta( $current_user->ID, 'billing_phone', true );
					
					$billing_f_name = get_user_meta( $userid, 'billing_first_name', true );
					$billing_l_name = get_user_meta( $userid, 'billing_last_name', true );
					$billing_company = get_user_meta( $userid, 'billing_company', true );
					
					$billing_full_name = $billing_f_name . ' ' . $billing_l_name;
					
					$shipping_f_name = get_user_meta( $userid, 'shipping_first_name', true );
					$shipping_l_name = get_user_meta( $userid, 'shipping_last_name', true );
					$shipping_company = get_user_meta( $userid, 'shipping_company', true );
					
					$shipping_full_name = $shipping_f_name . ' ' . $shipping_l_name;
					
					global $woocommerce;
					
					// Adresler		
					$faturaAdres = $woocommerce->customer->get_billing_address_1() . ' ' . $woocommerce->customer->get_billing_address_2() . ' ' . $woocommerce->customer->get_billing_postcode() . ' ' . $woocommerce->customer->get_billing_city () . ' ' . $woocommerce->customer->get_billing_country();
					
					$kargoAdres = $woocommerce->customer->get_shipping_address() . ' ' .  $woocommerce->customer->get_shipping_address_2() . ' ' . $woocommerce->customer->get_shipping_postcode() . ' ' . $woocommerce->customer->get_shipping_city() . ' ' . $woocommerce->customer->get_shipping_country();
					
					
					// Sepet Adet Tutar Ürün
					$cart_subtotal = strip_tags($woocommerce->cart->get_cart_subtotal());
					
					$cartitems = $woocommerce->cart->get_cart( );
					$cartitemstext = '';
					$toplamSepet = 0;
					$kargoucret = strip_tags($woocommerce->cart->get_cart_shipping_total());
					
					$cart_total_price = strip_tags($woocommerce->cart->get_total( ));
					
					foreach($cartitems as $cartitem => $values){
							$_product = $values['data']->post;
							$price = get_post_meta($values['product_id'] , '_price', true);
				
							$cartitemstext .= '<br />' . $values['quantity'] . ' Adet - ' . $_product->post_title . '. Fiyat: ₺' . $price;	
							$toplamSepet++;
						}
						
					$cartitemstext .= '<br />Ara Toplam : ' . $toplamSepet . ' Adet/<strong>' . $cart_subtotal . '</strong>';
					$cartitemstext .= '<br />Kargo Ücretleri : <strong>' . $kargoucret . '</strong>';
					$cartitemstext .= '<br /> ---------------------------------- <br /> Toplam : <strong>' . $cart_total_price . '</strong><br />';
					
					
					
					
					// Değiştirme
					// $content = apply_filters ("the_content", $post->post_content);
					
					$term_content = str_replace("[kullanici-adi]", $isim, $term_content);
					$term_content = str_replace("[tc-no]", $tckod, $term_content);
					$term_content = str_replace("[telefon-no]", $phone, $term_content);
					$term_content = str_replace("[e-posta-adresi]", $eposta, $term_content);
					
					$term_content = str_replace("[fatura-kullanici-adi]", $billing_full_name, $term_content);
					$term_content = str_replace("[fatura-firma-adi]", $billing_company, $term_content);
					$term_content = str_replace("[fatura-adresi]", $faturaAdres, $term_content);
					
					$term_content = str_replace("[kargo-kullanici-adi]", $shipping_full_name, $term_content);
					$term_content = str_replace("[kargo-firma-adi]", $shipping_company, $term_content);
					$term_content = str_replace("[kargo-adresi]", $kargoAdres, $term_content);
					
					$term_content = str_replace("[sepet-tutar]", $cartitemstext, $term_content);
					
					$term_content = str_replace("[tarih]", date("d/m/Y"), $term_content);
					
					echo $term_content;
				?>
					
			</div>	
		</div>
		
		<?php
		endif;
	} // cnk_terms_popup_content
	
}
